@@ -17,15 +17,13 @@ def cli():
 	root = util.find_root()
 	config = util.config()
 
-	click.echo('Spawning an interactive MySQL shell at %s' % config['hostname'])
-
 	os.execlp('ssh', 'ssh', '-t',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
 		'-o', 'IdentitiesOnly=yes',
 		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
 		'root@%s' % config['hostname'],
-		'docker exec -it sail sudo -u www-data wp --path=/var/www/public db cli'
+		'sudo -u www-data wp --path=%s db cli' % util.remote_path('/public')
 	)
 
 @db.command(name='import')
@@ -35,6 +33,7 @@ def import_cmd(path):
 	root = util.find_root()
 	config = util.config()
 	c = util.connection()
+	remote_path = util.remote_path()
 
 	path = pathlib.Path(path).resolve()
 	if not path.exists():
@@ -51,7 +50,7 @@ def import_cmd(path):
 
 	args = ['-t']
 	source = path
-	destination = 'root@%s:/var/www/%s' % (config['hostname'], temp_name)
+	destination = 'root@%s:%s/%s' % (config['hostname'], remote_path, temp_name)
 	returncode, stdout, stderr = util.rsync(args, source, destination, default_filters=False)
 
 	if returncode != 0:
@@ -64,14 +63,14 @@ def import_cmd(path):
 	cat_bin = 'zcat' if is_gz else 'cat'
 
 	try:
-		c.run('docker exec sail bash -c "%s /var/www/%s | mysql -uroot wordpress"' % (cat_bin, temp_name))
+		c.run('%s %s/%s | mysql -uroot "wordpress_%s"' % (cat_bin, remote_path, temp_name, config['namespace']))
 	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
 	click.echo('- Cleaning up production')
 
 	try:
-		c.run('docker exec sail rm /var/www/%s' % temp_name)
+		c.run('rm %s/%s' % (remote_path, temp_name))
 	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
@@ -83,6 +82,7 @@ def export():
 	root = util.find_root()
 	config = util.config()
 	c = util.connection()
+	remote_path = util.remote_path()
 
 	backups_dir = pathlib.Path(root + '/.backups')
 	backups_dir.mkdir(parents=True, exist_ok=True)
@@ -91,14 +91,14 @@ def export():
 	click.echo('# Exporting WordPress database')
 
 	try:
-		c.run('docker exec sail bash -c "mysqldump --quick --single-transaction --default-character-set=utf8mb4 -uroot wordpress | gzip -c9 > /var/www/%s"' % filename)
+		c.run('mysqldump --quick --single-transaction --default-character-set=utf8mb4 -uroot "wordpress_%s" | gzip -c9 > %s/%s' % (config['namespace'], remote_path, filename))
 	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
 	click.echo('- Export completed, downloading')
 
 	args = ['-t']
-	source = 'root@%s:/var/www/%s' % (config['hostname'], filename)
+	source = 'root@%s:%s/%s' % (config['hostname'], remote_path, filename)
 	destination = '%s/%s' % (backups_dir, filename)
 	returncode, stdout, stderr = util.rsync(args, source, destination, default_filters=False)
 
@@ -108,7 +108,7 @@ def export():
 	click.echo('- Cleaning up production')
 
 	try:
-		c.run('docker exec sail rm /var/www/%s' % filename)
+		c.run('rm %s/%s' % (remote_path, filename))
 	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
