@@ -2,7 +2,9 @@ from sail import cli, util
 
 import subprocess, time
 import click, pathlib
-import re, shlex
+import re, shlex, os, stat
+
+from glob import glob
 
 def _get_extend_filters(paths, prefix=None):
 	root = util.find_root()
@@ -55,50 +57,60 @@ def _get_extend_filters(paths, prefix=None):
 @click.argument('path', nargs=-1, required=False)
 @click.option('--with-uploads', is_flag=True, help='Include the wp-content/uploads directory')
 @click.option('--dry-run', is_flag=True, help='Show changes about to be deployed to production')
-def deploy(with_uploads, dry_run, path):
+@click.option('--skip-hooks', '--no-verify', is_flag=True, help='Do not run pre-deploy hooks')
+@click.pass_context
+def deploy(ctx, with_uploads, dry_run, path, skip_hooks):
 	'''Deploy your working copy to production. If path is not specified then all application files are deployed.'''
 	root = util.find_root()
 	config = util.config()
 
-	app_id = config['app_id']
 	release = str(int(time.time()))
 
 	if dry_run:
-		click.echo('# Comparing files')
-
-		destination = 'root@%s:/var/www/public/' % config['hostname']
-		source = '%s/' % root
-		files = _diff(source, destination, _get_extend_filters(path))
-		empty = True
-
-		colors = {'created': 'green', 'deleted': 'red', 'updated': 'yellow'}
-		labels = {'created': 'New', 'deleted': 'Delete', 'updated': 'Update'}
-		for op in ['created', 'updated', 'deleted']:
-			for filename in files[op]:
-				empty = False
-				click.secho('- %s: %s' % (labels[op], filename), fg=colors[op])
-
-		# TODO: Compare uploads if requested --with-uploads
-
-		if empty:
-			click.echo('- No changes')
-
-		return
+		return ctx.invoke(diff, path=path)
 
 	click.echo('# Deploying to production')
+
+	hooks = []
+	failed = []
+
+	if not skip_hooks:
+		hooks = glob(root + '/.sail/pre-deploy') + glob(root + '/.sail/pre-deploy.*')
+
+	if len(hooks) > 0:
+		click.echo('- Running pre-deploy hooks')
+
+	for hook in hooks:
+		f = pathlib.Path(hook)
+		if not os.access(f, os.X_OK):
+			f.chmod(f.stat().st_mode | stat.S_IEXEC)
+
+		p = subprocess.Popen(str(f), encoding='utf8', shell=True)
+		p.communicate()
+		if p.returncode > 0:
+			failed.append(f)
+
+	if len(failed) > 0:
+		click.echo('- One or more pre-deploy hooks failed. Aborting deploy.')
+		for f in failed:
+			click.echo('- Failed: %s' % f)
+
+		exit()
+
 	click.echo('- Preparing release directory')
 	c = util.connection()
+	remote_path = util.remote_path()
 
-	c.run('mkdir -p /var/www/releases/%s' % release)
-	c.run('rsync -rogtl /var/www/public/ /var/www/releases/%s' % release)
+	c.run('mkdir -p %s/releases/%s' % (remote_path, release))
+	c.run('rsync -rogtl %s/public/ %s/releases/%s' % (remote_path, remote_path, release))
 
 	click.echo('- Uploading application files to production')
 
 	returncode, stdout, stderr = util.rsync(
 		args=['-rtl', '--rsync-path', 'sudo -u www-data rsync',
-			'--copy-dest', '/var/www/public/', '--delete'],
+			'--copy-dest', '%s/public/' % remote_path, '--delete'],
 		source='%s/' % root,
-		destination='root@%s:/var/www/releases/%s' % (config['hostname'], release),
+		destination='root@%s:%s/releases/%s' % (config['hostname'], remote_path, release),
 		extend_filters=_get_extend_filters(path)
 	)
 
@@ -112,7 +124,7 @@ def deploy(with_uploads, dry_run, path):
 		returncode, stdout, stderr = util.rsync(
 			args=['-rtl', '--rsync-path', 'sudo -u www-data rsync', '--delete'],
 			source='%s/wp-content/uploads/' % root,
-			destination='root@%s:/var/www/uploads/' % config['hostname'],
+			destination='root@%s:%s/uploads/' % (config['hostname'], remote_path),
 			default_filters=False,
 			extend_filters=_get_extend_filters(path, 'wp-content/uploads')
 		)
@@ -123,14 +135,14 @@ def deploy(with_uploads, dry_run, path):
 	click.echo('- Deploying release: %s' % release)
 
 	click.echo('- Updating symlinks')
-	c.run('sudo -u www-data ln -sfn /var/www/uploads /var/www/releases/%s/wp-content/uploads' % release)
-	c.run('sudo -u www-data ln -sfn /var/www/releases/%s /var/www/public' % release)
+	c.run('sudo -u www-data ln -sfn %s/uploads %s/releases/%s/wp-content/uploads' % (remote_path, remote_path, release))
+	c.run('sudo -u www-data ln -sfn %s/releases/%s %s/public' % (remote_path, release, remote_path))
 
 	click.echo('- Reloading services')
-	c.run('docker exec sail nginx -s reload')
-	c.run('docker exec sail kill -s USR2 $(docker exec sail cat /var/run/php/php7.4-fpm.pid)')
+	c.run('nginx -s reload')
+	c.run('kill -s USR2 $(cat /var/run/php/php7.4-fpm.pid)')
 
-	releases = c.run('ls /var/www/releases')
+	releases = c.run('ls %s/releases' % remote_path)
 	releases = re.findall('\d+', releases.stdout)
 	releases = [int(i) for i in releases]
 
@@ -146,7 +158,7 @@ def deploy(with_uploads, dry_run, path):
 		click.echo('- Removing outdated releases')
 		remove = sorted(releases)[:len(releases)-keep]
 		for key in remove:
-			c.run(shlex.join(['rm', '-rf', '/var/www/releases/%s' % key]))
+			c.run(shlex.join(['rm', '-rf', '%s/releases/%s' % (remote_path, key)]))
 
 	click.echo('- Successfully deployed %s' % release)
 
@@ -157,16 +169,17 @@ def rollback(release=None, releases=False):
 	'''Rollback production to a previous release'''
 	sail = util.config()
 	c = util.connection()
+	remote_path = util.remote_path()
 
 	if releases or not release:
-		_releases = c.run('ls /var/www/releases')
+		_releases = c.run('ls %s/releases' % remote_path)
 		_releases = re.findall('\d+', _releases.stdout)
 
 		if len(_releases) < 1:
 			raise click.ClickException('Could not find any releases')
 
 		try:
-			_current = c.run('readlink /var/www/public').stdout.strip().split('/')[-1]
+			_current = c.run('readlink %s/public' % remote_path).stdout.strip().split('/')[-1]
 		except:
 			_current = '0'
 
@@ -184,16 +197,16 @@ def rollback(release=None, releases=False):
 
 	click.echo('# Rolling back to %s' % release)
 
-	_releases = c.run('ls /var/www/releases').stdout.strip().split('\n')
+	_releases = c.run('ls %s/releases' % remote_path).stdout.strip().split('\n')
 	if release not in _releases:
 		raise click.ClickException('Invalid release. To get a list run: sail rollback --releases')
 
 	click.echo('- Updating symlinks')
-	c.run('ln -sfn /var/www/releases/%s /var/www/public' % release)
+	c.run('ln -sfn %s/releases/%s %s/public' % (remote_path, release, remote_path))
 
 	click.echo('- Reloading services')
-	c.run('docker exec sail nginx -s reload')
-	c.run('docker exec sail kill -s USR2 $(docker exec sail cat /var/run/php/php7.4-fpm.pid)')
+	c.run('nginx -s reload')
+	c.run('kill -s USR2 $(cat /var/run/php/php7.4-fpm.pid)')
 
 	click.echo('- Successfully rolled back to %s' % release)
 
@@ -203,7 +216,8 @@ def rollback(release=None, releases=False):
 @click.option('--with-uploads', is_flag=True, help='Include the wp-content/uploads directory')
 @click.option('--delete', is_flag=True, help='Delete files from local copy that do not exist on production')
 @click.option('--dry-run', is_flag=True, help='Show changes about to be downloaded to the working copy')
-def download(path, yes, with_uploads, delete, dry_run):
+@click.pass_context
+def download(ctx, path, yes, with_uploads, delete, dry_run):
 	'''Download files from production to your working copy'''
 	root = util.find_root()
 	config = util.config()
@@ -214,36 +228,16 @@ def download(path, yes, with_uploads, delete, dry_run):
 			abort=True
 		)
 
-	app_id = config['app_id']
 	delete = ['--delete'] if delete else []
 
 	if dry_run:
-		click.echo('# Comparing files')
-
-		source = 'root@%s:/var/www/public/' % config['hostname']
-		destination = '%s/' % root
-		files = _diff(source, destination, _get_extend_filters(path))
-		empty = True
-
-		colors = {'created': 'green', 'deleted': 'red', 'updated': 'yellow'}
-		labels = {'created': 'New', 'deleted': 'Delete', 'updated': 'Update'}
-		for op in ['created', 'updated', 'deleted']:
-			for filename in files[op]:
-				empty = False
-				click.secho('- %s: %s' % (labels[op], filename), fg=colors[op])
-
-		# TODO: Compare uploads if requested --with-uploads
-
-		if empty:
-			click.echo('- No changes')
-
-		return
+		return ctx.invoke(diff, path=path, reverse=True)
 
 	click.echo('# Downloading application files from production')
 
 	returncode, stdout, stderr = util.rsync(
 		args=['-rtl'] + delete,
-		source='root@%s:/var/www/public/' % config['hostname'],
+		source='root@%s:%s' % (config['hostname'], util.remote_path('/public/')),
 		destination='%s/' % root,
 		extend_filters=_get_extend_filters(path)
 	)
@@ -257,7 +251,7 @@ def download(path, yes, with_uploads, delete, dry_run):
 		# Download uploads from production
 		returncode, stdout, stderr = util.rsync(
 			args=['-rtl'] + delete,
-			source='root@%s:/var/www/uploads/' % config['hostname'],
+			source='root@%s:%s' % (config['hostname'], util.remote_path('/uploads/')),
 			destination='%s/wp-content/uploads/' % root,
 			default_filters=False,
 			extend_filters=_get_extend_filters(path, 'wp-content/uploads')
@@ -268,6 +262,44 @@ def download(path, yes, with_uploads, delete, dry_run):
 
 	click.echo('- Files download completed')
 
+@cli.command()
+@click.argument('path', nargs=-1, required=False)
+@click.option('--reverse', is_flag=True, help='Reverse the file comparison direction (production to local)')
+@click.option('--raw', is_flag=True, help='Show the list of changes in raw format')
+def diff(path, reverse, raw):
+	'''Show file changes between your local copy and production.'''
+	root = util.find_root()
+	config = util.config()
+
+	if raw:
+		util.loader(suspend=True)
+	else:
+		click.echo('# Comparing files')
+
+	destination = 'root@%s:%s' % (config['hostname'], util.remote_path('/public/'))
+	source = '%s/' % root
+
+	if reverse:
+		destination, source = source, destination
+
+	files = _diff(source, destination, _get_extend_filters(path))
+	empty = True
+
+	colors = {'created': 'green', 'deleted': 'red', 'updated': 'yellow'}
+	labels = {'created': 'New', 'deleted': 'Delete', 'updated': 'Update'}
+	for op in ['created', 'updated', 'deleted']:
+		for filename in files[op]:
+			empty = False
+			if raw:
+				click.echo(filename)
+			else:
+				click.secho('- %s: %s' % (labels[op], filename), fg=colors[op])
+
+	# TODO: Compare uploads if requested --with-uploads
+
+	if empty and not raw:
+		click.echo('- No changes')
+
 def _diff(source, destination, extend_filters=[]):
 	'''Compare application files between environments'''
 	root = util.find_root()
