@@ -6,9 +6,8 @@ import requests
 
 @cli.group(invoke_without_command=True)
 @click.option('--root', is_flag=True, help='Login as the root user')
-@click.option('--host', is_flag=True, help='Login to the host (not the container) as the root user')
 @click.pass_context
-def ssh(ctx, root, host):
+def ssh(ctx, root):
 	'''Open an SSH shell, manage SSH keys and more'''
 	# Default subcommand for back-compat
 	if not ctx.invoked_subcommand:
@@ -149,27 +148,22 @@ def delete(hash):
 
 @ssh.command()
 @click.option('--root', is_flag=True, help='Login as the root user')
-@click.option('--host', is_flag=True, help='Login to the host (not the container) as the root user')
-def shell(root, host):
-	'''Open an interactive SSH shell to the production container or host'''
+def shell(root):
+	'''Open an interactive SSH shell to the production host'''
 	as_root = root
 	root = util.find_root()
 	config = util.config()
 
 	command = ''
-
-	if not host and as_root:
-		command = 'docker exec -it sail bash'
-	elif not host and not as_root:
-		command = 'docker exec -it sail sudo -u www-data bash -c "cd ~/public; bash"'
-
-	click.echo('Spawning an interactive SSH shell for %s' % config['hostname'])
+	if not as_root:
+		command = 'sudo -u www-data bash -c "cd %s; bash"' % util.remote_path('/public')
 
 	os.execlp('ssh', 'ssh', '-tt',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
 		'-o', 'IdentitiesOnly=yes',
 		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
+		'-o', 'LogLevel=QUIET',
 		'root@%s' % config['hostname'],
 		command
 	)
@@ -177,8 +171,7 @@ def shell(root, host):
 @ssh.command(context_settings=dict(ignore_unknown_options=True))
 @click.argument('command', nargs=-1)
 @click.option('--root', is_flag=True, help='Login as the root user')
-@click.option('--host', is_flag=True, help='Login to the host (not the container) as the root user')
-def run(command, root, host):
+def run(command, root):
 	'''Run a command via SSH and return the results'''
 	as_root = root
 	root = util.find_root()
@@ -189,18 +182,15 @@ def run(command, root, host):
 	else:
 		command = ''.join(command)
 
-	if not host and as_root:
-		command = shlex.join(['docker', 'exec', '-it', 'sail', 'bash', '-c', command])
-	elif not host and not as_root:
-		command = shlex.join(['docker', 'exec', '-it', 'sail', 'sudo', '-u', 'www-data', 'bash', '-c', command])
-
-	click.echo('Spawning SSH and running command on %s' % config['hostname'], err=True)
+	if not as_root:
+		command = shlex.join(['sudo', '-u', 'www-data', 'bash', '-c', command])
 
 	os.execlp('ssh', 'ssh', '-tt',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
 		'-o', 'IdentitiesOnly=yes',
 		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
+		'-o', 'LogLevel=QUIET',
 		'root@%s' % config['hostname'],
 		command
 	)
